Corex.Tree (Corex v0.1.0-alpha.29)

Tree items for hierarchical/nested structures to be used with:

Use Corex.Tree.new/1 to build a list of items from keyword lists or maps.

Summary

Functions

Creates a list of Tree.Item structs from a list of attribute maps. Recursively processes children if present.

Functions

new(items)

Creates a list of Tree.Item structs from a list of attribute maps. Recursively processes children if present.

Raises ArgumentError if items is not a list or contains invalid items.