Corex.Tree.Item
(Corex v0.1.0-alpha.29)
Tree item structure.
Use it to create hierarchical/nested structures for:
Fields
:id- (optional) Unique identifier, auto-generated if not provided:label- (required) Display text:children- (optional) Nested items:disabled- (optional) Whether the item is disabled:group- (optional) Group identifier for grouping items:meta- (optional) Additional metadata for the item:redirect- (optional) When top-level redirect is true, set to false on an item to disable redirect for that item:new_tab- (optional) When redirect is used, set to true to open this item's URL in a new tab
Summary
Functions
Creates a single Tree.Item with an auto-generated ID if not provided. Recursively processes children if present.
Types
Functions
Creates a single Tree.Item with an auto-generated ID if not provided. Recursively processes children if present.
Raises ArgumentError if attrs is not a keyword list or map.