mix corex.new.web (Corex v0.1.0-alpha.33)

Creates a new Phoenix web application inside an existing umbrella project.

This task is only for use within an umbrella project. It must be run from the umbrella's apps directory. It creates a new web app (with Corex and Phoenix) that can depend on other apps in the umbrella. For a standalone project, use mix corex.new instead.

It expects the name of the OTP app as the first argument:

$ cd my_umbrella/apps
$ mix corex.new.web APP [--module MODULE] [--app APP]

The generated app is a bare Phoenix web project without database integration by default, which you can then wire to your umbrella's domain app(s).

Examples

$ mix corex.new.web hello_web

Is equivalent to:

$ mix corex.new.web hello_web --module HelloWeb

For all available options (e.g. --umbrella, --no-ecto, --theme), see Mix.Tasks.Corex.New.