mix local.corex (Corex v0.1.0-alpha.33)

Updates the Corex project generator used by mix corex.new.

Run this when you want the next mix corex.new to use the latest generator templates and options. It delegates to archive.install hex corex_new and accepts the same command line options (e.g. --force to reinstall without prompting).

$ mix local.corex