Corex.List
(Corex v0.1.0-alpha.29)
List items for flat selectable items to be used with:
Use Corex.List.new/1 to build a list of items from keyword lists or maps.
Summary
Functions
Creates a list of List.Item structs from a list of attribute maps.
Functions
Creates a list of List.Item structs from a list of attribute maps.
Raises ArgumentError if items is not a list or contains invalid items.